Main Window
===========


Parameter Input
---------------

In general, real parameter values can be set using expressions just like
parameter values can be set using expressions on the *Tao* command line.

The Main GUI Window
-------------------


.. figure:: /_static/gui/figures/root_window.png
   :align: center
   :alt: The main GUI window.

   The main GUI window, showing the results of *show data* on the console.

The main window for the GUI is shown in the figure above.
From here, the user has access to all of the GUI's features.
Command files can be called by browsing for them and then clicking "Run", with
arguments specified in the "Arguments" below.
In the future, the user will also be able to set up and run optimization
routines from this window, although this feature is not currently available.

The main window also has a console, where commands can be run in Tao exactly
like in regular *Tao*.
The console will also display warning messages if a command produces an error.


